@@ -73,17 +73,28 @@ Q_GLOBAL_STATIC(QIconLoader, iconLoaderInstance)
 static QString fallbackTheme()
 {
 #ifdef Q_WS_X11
-    if (X11->desktopEnvironment == DE_GNOME) {
+    switch (X11->desktopEnvironment) {
+    case DE_GNOME:
+    case DE_CYGWIN:
+        return QLatin1String("Adwaita");
+    case DE_CINNAMON:
         return QLatin1String("gnome");
-    } else if (X11->desktopEnvironment == DE_MATE) {
-        return QLatin1String("mate");
-    } else if (X11->desktopEnvironment == DE_LXDE) {
+    case DE_LXDE:
         return QLatin1String("nuoveXT2");
-    } else if (X11->desktopEnvironment == DE_KDE) {
-        return X11->desktopVersion >= 4
-            ? QString::fromLatin1("oxygen")
-            : QString::fromLatin1("crystalsvg");
-    } else {
+    case DE_LXQT:
+        return QLatin1String("oxygen");
+    case DE_MATE:
+        return QLatin1String("menta");
+    case DE_XFCE:
+        return QLatin1String("Rodent");
+    case DE_KDE:
+        if (X11->desktopVersion >= 5)
+            return QLatin1String("breeze");
+        else if (X11->desktopVersion == 4)
+            return QLatin1String("oxygen");
+        else
+            return QLatin1String("crystalsvg");
+    default:
         return QLatin1String("hicolor");
     }
 #endif
