@@ -1020,10 +1020,20 @@ QFontEngineX11FT::QFontEngineX11FT(FcPattern *pattern, const QFontDef &fd, int s
         int hint_style = 0;
         // Try to use Xft.hintstyle from XDefaults first if running in GNOME, to match
         // the behavior of cairo
-        if (X11->fc_hint_style > -1 && (X11->desktopEnvironment == DE_GNOME
-                                        || X11->desktopEnvironment == DE_MATE
-                                        || X11->desktopEnvironment == DE_LXDE))
-            hint_style = X11->fc_hint_style;
+        if (X11->fc_hint_style > -1) {
+            switch (X11->desktopEnvironment) {
+            case DE_GNOME:
+            case DE_CINNAMON:
+            case DE_CYGWIN:
+            case DE_LXDE:
+            case DE_MATE:
+            case DE_XFCE:
+                hint_style = X11->fc_hint_style;
+                break;
+            default:
+                break;
+            }
+        }
         else if (FcPatternGetInteger (pattern, FC_HINT_STYLE, 0, &hint_style) == FcResultNoMatch
                  && X11->fc_hint_style > -1)
             hint_style = X11->fc_hint_style;
